Structs
- Supabase
Client Wrapper - Wraps Supabase sub-clients and manages configuration/state.
- Supabase
Config - Configuration for the Supabase client. It’s recommended to load these values from environment variables or a secure config source.
Enums
- Item
Change - Represents the different types of changes received from a realtime subscription.