Module error

Module error 

Enums

SupabaseError
Universal error type for the Supabase client library operations. This now mostly wraps or maps errors from the supabase_rust_gftd crate.

Type Aliases

Result