pub enum SupabaseError {
}Expand description
Universal error type for the Supabase client library operations.
This now mostly wraps or maps errors from the supabase_rust_gftd crate.
Variants
Config(String)
Initialization(String)
Auth(AuthError)
Postgrest(PostgrestError)
Realtime(String)
Storage(String)
Function(String)
Network(Error)
UrlParse(ParseError)
Json(Error)
InvalidInput(String)
Timeout
Internal(String)
Unknown