Module error
supabase_
rust_
client
0.4.0
Module error
Module Items
Enums
Type Aliases
In crate supabase_
rust_
client
supabase_rust_client
Module
error
Enums

Supabase
Error
Universal error type for the Supabase client library operations. This now mostly wraps or maps errors from the
supabase_rust_gftd
crate.
Type Aliases

Result